summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umllistviewitem.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /umbrello/umbrello/umllistviewitem.h
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/umllistviewitem.h')
-rw-r--r--umbrello/umbrello/umllistviewitem.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/umbrello/umbrello/umllistviewitem.h b/umbrello/umbrello/umllistviewitem.h
index 105b751e..596a93f5 100644
--- a/umbrello/umbrello/umllistviewitem.h
+++ b/umbrello/umbrello/umllistviewitem.h
@@ -38,46 +38,46 @@ public:
/**
* Sets up an instance.
*
* @param tqparent The tqparent to this instance.
* @param name The name of this instance.
* @param t The type of this instance.
* @param o The object it represents.
*/
- UMLListViewItem(UMLListView * tqparent, const TQString &name, Uml::ListView_Type t, UMLObject*o=0);
+ UMLListViewItem(UMLListView * parent, const TQString &name, Uml::ListView_Type t, UMLObject*o=0);
/**
* Sets up an instance for subsequent loadFromXMI().
*
* @param tqparent The tqparent to this instance.
*/
- UMLListViewItem(UMLListView * tqparent);
+ UMLListViewItem(UMLListView * parent);
/**
* Sets up an instance for subsequent loadFromXMI().
*
* @param tqparent The tqparent to this instance.
*/
- UMLListViewItem(UMLListViewItem * tqparent);
+ UMLListViewItem(UMLListViewItem * parent);
/**
* Sets up an instance.
*
* @param tqparent The tqparent to this instance.
* @param name The name of this instance.
* @param t The type of this instance.
* @param o The object it represents.
*/
- UMLListViewItem(UMLListViewItem * tqparent, const TQString &name, Uml::ListView_Type t, UMLObject*o=0);
+ UMLListViewItem(UMLListViewItem * parent, const TQString &name, Uml::ListView_Type t, UMLObject*o=0);
/**
* Sets up an instance.
*
* @param tqparent The tqparent to this instance.
* @param name The name of this instance.
* @param t The type of this instance.
* @param id The id of this instance.
*/
- UMLListViewItem(UMLListViewItem * tqparent, const TQString &name, Uml::ListView_Type t, Uml::IDType id);
+ UMLListViewItem(UMLListViewItem * parent, const TQString &name, Uml::ListView_Type t, Uml::IDType id);
/**
* Standard deconstructor.
@@ -126,7 +126,7 @@ public:
}
/**
* Returns true if the UMLListViewItem of the given ID is a tqparent of
* this UMLListViewItem.
*/
bool isOwnParent(Uml::IDType listViewItemID);
@@ -199,7 +199,7 @@ public:
/**
* Create a deep copy of this UMLListViewItem, but using the
* given tqparent instead of the tqparent of this UMLListViewItem.
* Return the new UMLListViewItem created.
*/
UMLListViewItem* deepCopy(UMLListViewItem *newParent);
@@ -243,7 +243,7 @@ protected:
/**
* Initializes key variables of the class.
*/
- void init(UMLListView * tqparent = 0);
+ void init(UMLListView * parent = 0);
/**
* This function is called if the user presses Enter during in-place renaming
@@ -38,46 +38,46 @@ public:
* Sets up an instance.
*
- * @param tqparent The tqparent to this instance.
+ * @param parent The parent to this instance.
* @param name The name of this instance.
* @param t The type of this instance.
@@ -38,46 +38,46 @@ public:
* Sets up an instance for subsequent loadFromXMI().
*
- * @param tqparent The tqparent to this instance.
+ * @param parent The parent to this instance.
*/
@@ -38,46 +38,46 @@ public:
* Sets up an instance for subsequent loadFromXMI().
*
- * @param tqparent The tqparent to this instance.
+ * @param parent The parent to this instance.
*/
@@ -38,46 +38,46 @@ public:
* Sets up an instance.
*
- * @param tqparent The tqparent to this instance.
+ * @param parent The parent to this instance.
* @param name The name of this instance.
* @param t The type of this instance.
@@ -38,46 +38,46 @@ public:
* Sets up an instance.
*
- * @param tqparent The tqparent to this instance.
+ * @param parent The parent to this instance.
* @param name The name of this instance.
* @param t The type of this instance.
@@ -126,7 +126,7 @@ public:
}
/**
- * Returns true if the UMLListViewItem of the given ID is a tqparent of
+ * Returns true if the UMLListViewItem of the given ID is a parent of
* this UMLListViewItem.
*/
@@ -199,7 +199,7 @@ public:
/**
* Create a deep copy of this UMLListViewItem, but using the
- * given tqparent instead of the tqparent of this UMLListViewItem.
+ * given parent instead of the parent of this UMLListViewItem.
* Return the new UMLListViewItem created.
*/